# coding: utf-8

"""
    Kodexa

    Content Intelligence  # noqa: E501

    OpenAPI spec version: 2.0.132
    Contact: suppot@kodexa.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class PlatformUser(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'activated': 'bool',
        'created_by': 'str',
        'created_on': 'Timestamp',
        'email': 'str',
        'first_name': 'str',
        'id': 'str',
        'last_name': 'str',
        'password_reset_date': 'Timestamp',
        'platform_admin': 'bool',
        'updated_by': 'str',
        'updated_on': 'Timestamp',
        'uuid': 'str'
    }

    attribute_map = {
        'activated': 'activated',
        'created_by': 'createdBy',
        'created_on': 'createdOn',
        'email': 'email',
        'first_name': 'firstName',
        'id': 'id',
        'last_name': 'lastName',
        'password_reset_date': 'passwordResetDate',
        'platform_admin': 'platformAdmin',
        'updated_by': 'updatedBy',
        'updated_on': 'updatedOn',
        'uuid': 'uuid'
    }

    def __init__(self, activated=None, created_by=None, created_on=None, email=None, first_name=None, id=None, last_name=None, password_reset_date=None, platform_admin=None, updated_by=None, updated_on=None, uuid=None):  # noqa: E501
        """PlatformUser - a model defined in Swagger"""  # noqa: E501
        self._activated = None
        self._created_by = None
        self._created_on = None
        self._email = None
        self._first_name = None
        self._id = None
        self._last_name = None
        self._password_reset_date = None
        self._platform_admin = None
        self._updated_by = None
        self._updated_on = None
        self._uuid = None
        self.discriminator = None
        if activated is not None:
            self.activated = activated
        if created_by is not None:
            self.created_by = created_by
        if created_on is not None:
            self.created_on = created_on
        if email is not None:
            self.email = email
        if first_name is not None:
            self.first_name = first_name
        if id is not None:
            self.id = id
        if last_name is not None:
            self.last_name = last_name
        if password_reset_date is not None:
            self.password_reset_date = password_reset_date
        if platform_admin is not None:
            self.platform_admin = platform_admin
        if updated_by is not None:
            self.updated_by = updated_by
        if updated_on is not None:
            self.updated_on = updated_on
        if uuid is not None:
            self.uuid = uuid

    @property
    def activated(self):
        """Gets the activated of this PlatformUser.  # noqa: E501


        :return: The activated of this PlatformUser.  # noqa: E501
        :rtype: bool
        """
        return self._activated

    @activated.setter
    def activated(self, activated):
        """Sets the activated of this PlatformUser.


        :param activated: The activated of this PlatformUser.  # noqa: E501
        :type: bool
        """

        self._activated = activated

    @property
    def created_by(self):
        """Gets the created_by of this PlatformUser.  # noqa: E501


        :return: The created_by of this PlatformUser.  # noqa: E501
        :rtype: str
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """Sets the created_by of this PlatformUser.


        :param created_by: The created_by of this PlatformUser.  # noqa: E501
        :type: str
        """

        self._created_by = created_by

    @property
    def created_on(self):
        """Gets the created_on of this PlatformUser.  # noqa: E501


        :return: The created_on of this PlatformUser.  # noqa: E501
        :rtype: Timestamp
        """
        return self._created_on

    @created_on.setter
    def created_on(self, created_on):
        """Sets the created_on of this PlatformUser.


        :param created_on: The created_on of this PlatformUser.  # noqa: E501
        :type: Timestamp
        """

        self._created_on = created_on

    @property
    def email(self):
        """Gets the email of this PlatformUser.  # noqa: E501


        :return: The email of this PlatformUser.  # noqa: E501
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this PlatformUser.


        :param email: The email of this PlatformUser.  # noqa: E501
        :type: str
        """

        self._email = email

    @property
    def first_name(self):
        """Gets the first_name of this PlatformUser.  # noqa: E501


        :return: The first_name of this PlatformUser.  # noqa: E501
        :rtype: str
        """
        return self._first_name

    @first_name.setter
    def first_name(self, first_name):
        """Sets the first_name of this PlatformUser.


        :param first_name: The first_name of this PlatformUser.  # noqa: E501
        :type: str
        """

        self._first_name = first_name

    @property
    def id(self):
        """Gets the id of this PlatformUser.  # noqa: E501


        :return: The id of this PlatformUser.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this PlatformUser.


        :param id: The id of this PlatformUser.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def last_name(self):
        """Gets the last_name of this PlatformUser.  # noqa: E501


        :return: The last_name of this PlatformUser.  # noqa: E501
        :rtype: str
        """
        return self._last_name

    @last_name.setter
    def last_name(self, last_name):
        """Sets the last_name of this PlatformUser.


        :param last_name: The last_name of this PlatformUser.  # noqa: E501
        :type: str
        """

        self._last_name = last_name

    @property
    def password_reset_date(self):
        """Gets the password_reset_date of this PlatformUser.  # noqa: E501


        :return: The password_reset_date of this PlatformUser.  # noqa: E501
        :rtype: Timestamp
        """
        return self._password_reset_date

    @password_reset_date.setter
    def password_reset_date(self, password_reset_date):
        """Sets the password_reset_date of this PlatformUser.


        :param password_reset_date: The password_reset_date of this PlatformUser.  # noqa: E501
        :type: Timestamp
        """

        self._password_reset_date = password_reset_date

    @property
    def platform_admin(self):
        """Gets the platform_admin of this PlatformUser.  # noqa: E501


        :return: The platform_admin of this PlatformUser.  # noqa: E501
        :rtype: bool
        """
        return self._platform_admin

    @platform_admin.setter
    def platform_admin(self, platform_admin):
        """Sets the platform_admin of this PlatformUser.


        :param platform_admin: The platform_admin of this PlatformUser.  # noqa: E501
        :type: bool
        """

        self._platform_admin = platform_admin

    @property
    def updated_by(self):
        """Gets the updated_by of this PlatformUser.  # noqa: E501


        :return: The updated_by of this PlatformUser.  # noqa: E501
        :rtype: str
        """
        return self._updated_by

    @updated_by.setter
    def updated_by(self, updated_by):
        """Sets the updated_by of this PlatformUser.


        :param updated_by: The updated_by of this PlatformUser.  # noqa: E501
        :type: str
        """

        self._updated_by = updated_by

    @property
    def updated_on(self):
        """Gets the updated_on of this PlatformUser.  # noqa: E501


        :return: The updated_on of this PlatformUser.  # noqa: E501
        :rtype: Timestamp
        """
        return self._updated_on

    @updated_on.setter
    def updated_on(self, updated_on):
        """Sets the updated_on of this PlatformUser.


        :param updated_on: The updated_on of this PlatformUser.  # noqa: E501
        :type: Timestamp
        """

        self._updated_on = updated_on

    @property
    def uuid(self):
        """Gets the uuid of this PlatformUser.  # noqa: E501


        :return: The uuid of this PlatformUser.  # noqa: E501
        :rtype: str
        """
        return self._uuid

    @uuid.setter
    def uuid(self, uuid):
        """Sets the uuid of this PlatformUser.


        :param uuid: The uuid of this PlatformUser.  # noqa: E501
        :type: str
        """

        self._uuid = uuid

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(PlatformUser, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PlatformUser):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Kodexa

    Content Intelligence  # noqa: E501

    OpenAPI spec version: 2.0.132
    Contact: suppot@kodexa.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class ContentServiceReference(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'attach_source': 'bool',
        'content_service_id': 'str',
        'content_service_version_id': 'str',
        'ref': 'str'
    }

    attribute_map = {
        'attach_source': 'attachSource',
        'content_service_id': 'contentServiceId',
        'content_service_version_id': 'contentServiceVersionId',
        'ref': 'ref'
    }

    def __init__(self, attach_source=None, content_service_id=None, content_service_version_id=None, ref=None):  # noqa: E501
        """ContentServiceReference - a model defined in Swagger"""  # noqa: E501
        self._attach_source = None
        self._content_service_id = None
        self._content_service_version_id = None
        self._ref = None
        self.discriminator = None
        if attach_source is not None:
            self.attach_source = attach_source
        if content_service_id is not None:
            self.content_service_id = content_service_id
        if content_service_version_id is not None:
            self.content_service_version_id = content_service_version_id
        if ref is not None:
            self.ref = ref

    @property
    def attach_source(self):
        """Gets the attach_source of this ContentServiceReference.  # noqa: E501


        :return: The attach_source of this ContentServiceReference.  # noqa: E501
        :rtype: bool
        """
        return self._attach_source

    @attach_source.setter
    def attach_source(self, attach_source):
        """Sets the attach_source of this ContentServiceReference.


        :param attach_source: The attach_source of this ContentServiceReference.  # noqa: E501
        :type: bool
        """

        self._attach_source = attach_source

    @property
    def content_service_id(self):
        """Gets the content_service_id of this ContentServiceReference.  # noqa: E501


        :return: The content_service_id of this ContentServiceReference.  # noqa: E501
        :rtype: str
        """
        return self._content_service_id

    @content_service_id.setter
    def content_service_id(self, content_service_id):
        """Sets the content_service_id of this ContentServiceReference.


        :param content_service_id: The content_service_id of this ContentServiceReference.  # noqa: E501
        :type: str
        """

        self._content_service_id = content_service_id

    @property
    def content_service_version_id(self):
        """Gets the content_service_version_id of this ContentServiceReference.  # noqa: E501


        :return: The content_service_version_id of this ContentServiceReference.  # noqa: E501
        :rtype: str
        """
        return self._content_service_version_id

    @content_service_version_id.setter
    def content_service_version_id(self, content_service_version_id):
        """Sets the content_service_version_id of this ContentServiceReference.


        :param content_service_version_id: The content_service_version_id of this ContentServiceReference.  # noqa: E501
        :type: str
        """

        self._content_service_version_id = content_service_version_id

    @property
    def ref(self):
        """Gets the ref of this ContentServiceReference.  # noqa: E501


        :return: The ref of this ContentServiceReference.  # noqa: E501
        :rtype: str
        """
        return self._ref

    @ref.setter
    def ref(self, ref):
        """Sets the ref of this ContentServiceReference.


        :param ref: The ref of this ContentServiceReference.  # noqa: E501
        :type: str
        """

        self._ref = ref

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ContentServiceReference, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ContentServiceReference):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Kodexa

    Content Intelligence  # noqa: E501

    OpenAPI spec version: 2.0.132
    Contact: suppot@kodexa.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class PipelineStepMetadata(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'options': 'object',
        'organization_slug': 'str',
        'slug': 'str'
    }

    attribute_map = {
        'name': 'name',
        'options': 'options',
        'organization_slug': 'organizationSlug',
        'slug': 'slug'
    }

    def __init__(self, name=None, options=None, organization_slug=None, slug=None):  # noqa: E501
        """PipelineStepMetadata - a model defined in Swagger"""  # noqa: E501
        self._name = None
        self._options = None
        self._organization_slug = None
        self._slug = None
        self.discriminator = None
        if name is not None:
            self.name = name
        if options is not None:
            self.options = options
        if organization_slug is not None:
            self.organization_slug = organization_slug
        if slug is not None:
            self.slug = slug

    @property
    def name(self):
        """Gets the name of this PipelineStepMetadata.  # noqa: E501


        :return: The name of this PipelineStepMetadata.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this PipelineStepMetadata.


        :param name: The name of this PipelineStepMetadata.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def options(self):
        """Gets the options of this PipelineStepMetadata.  # noqa: E501


        :return: The options of this PipelineStepMetadata.  # noqa: E501
        :rtype: object
        """
        return self._options

    @options.setter
    def options(self, options):
        """Sets the options of this PipelineStepMetadata.


        :param options: The options of this PipelineStepMetadata.  # noqa: E501
        :type: object
        """

        self._options = options

    @property
    def organization_slug(self):
        """Gets the organization_slug of this PipelineStepMetadata.  # noqa: E501


        :return: The organization_slug of this PipelineStepMetadata.  # noqa: E501
        :rtype: str
        """
        return self._organization_slug

    @organization_slug.setter
    def organization_slug(self, organization_slug):
        """Sets the organization_slug of this PipelineStepMetadata.


        :param organization_slug: The organization_slug of this PipelineStepMetadata.  # noqa: E501
        :type: str
        """

        self._organization_slug = organization_slug

    @property
    def slug(self):
        """Gets the slug of this PipelineStepMetadata.  # noqa: E501


        :return: The slug of this PipelineStepMetadata.  # noqa: E501
        :rtype: str
        """
        return self._slug

    @slug.setter
    def slug(self, slug):
        """Sets the slug of this PipelineStepMetadata.


        :param slug: The slug of this PipelineStepMetadata.  # noqa: E501
        :type: str
        """

        self._slug = slug

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(PipelineStepMetadata, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PipelineStepMetadata):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Kodexa

    Content Intelligence  # noqa: E501

    OpenAPI spec version: 2.0.132
    Contact: suppot@kodexa.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class Timestamp(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        '_date': 'int',
        'day': 'int',
        'hours': 'int',
        'minutes': 'int',
        'month': 'int',
        'nanos': 'int',
        'seconds': 'int',
        'time': 'int',
        'timezone_offset': 'int',
        'year': 'int'
    }

    attribute_map = {
        '_date': 'date',
        'day': 'day',
        'hours': 'hours',
        'minutes': 'minutes',
        'month': 'month',
        'nanos': 'nanos',
        'seconds': 'seconds',
        'time': 'time',
        'timezone_offset': 'timezoneOffset',
        'year': 'year'
    }

    def __init__(self, _date=None, day=None, hours=None, minutes=None, month=None, nanos=None, seconds=None, time=None, timezone_offset=None, year=None):  # noqa: E501
        """Timestamp - a model defined in Swagger"""  # noqa: E501
        self.__date = None
        self._day = None
        self._hours = None
        self._minutes = None
        self._month = None
        self._nanos = None
        self._seconds = None
        self._time = None
        self._timezone_offset = None
        self._year = None
        self.discriminator = None
        if _date is not None:
            self._date = _date
        if day is not None:
            self.day = day
        if hours is not None:
            self.hours = hours
        if minutes is not None:
            self.minutes = minutes
        if month is not None:
            self.month = month
        if nanos is not None:
            self.nanos = nanos
        if seconds is not None:
            self.seconds = seconds
        if time is not None:
            self.time = time
        if timezone_offset is not None:
            self.timezone_offset = timezone_offset
        if year is not None:
            self.year = year

    @property
    def _date(self):
        """Gets the _date of this Timestamp.  # noqa: E501


        :return: The _date of this Timestamp.  # noqa: E501
        :rtype: int
        """
        return self.__date

    @_date.setter
    def _date(self, _date):
        """Sets the _date of this Timestamp.


        :param _date: The _date of this Timestamp.  # noqa: E501
        :type: int
        """

        self.__date = _date

    @property
    def day(self):
        """Gets the day of this Timestamp.  # noqa: E501


        :return: The day of this Timestamp.  # noqa: E501
        :rtype: int
        """
        return self._day

    @day.setter
    def day(self, day):
        """Sets the day of this Timestamp.


        :param day: The day of this Timestamp.  # noqa: E501
        :type: int
        """

        self._day = day

    @property
    def hours(self):
        """Gets the hours of this Timestamp.  # noqa: E501


        :return: The hours of this Timestamp.  # noqa: E501
        :rtype: int
        """
        return self._hours

    @hours.setter
    def hours(self, hours):
        """Sets the hours of this Timestamp.


        :param hours: The hours of this Timestamp.  # noqa: E501
        :type: int
        """

        self._hours = hours

    @property
    def minutes(self):
        """Gets the minutes of this Timestamp.  # noqa: E501


        :return: The minutes of this Timestamp.  # noqa: E501
        :rtype: int
        """
        return self._minutes

    @minutes.setter
    def minutes(self, minutes):
        """Sets the minutes of this Timestamp.


        :param minutes: The minutes of this Timestamp.  # noqa: E501
        :type: int
        """

        self._minutes = minutes

    @property
    def month(self):
        """Gets the month of this Timestamp.  # noqa: E501


        :return: The month of this Timestamp.  # noqa: E501
        :rtype: int
        """
        return self._month

    @month.setter
    def month(self, month):
        """Sets the month of this Timestamp.


        :param month: The month of this Timestamp.  # noqa: E501
        :type: int
        """

        self._month = month

    @property
    def nanos(self):
        """Gets the nanos of this Timestamp.  # noqa: E501


        :return: The nanos of this Timestamp.  # noqa: E501
        :rtype: int
        """
        return self._nanos

    @nanos.setter
    def nanos(self, nanos):
        """Sets the nanos of this Timestamp.


        :param nanos: The nanos of this Timestamp.  # noqa: E501
        :type: int
        """

        self._nanos = nanos

    @property
    def seconds(self):
        """Gets the seconds of this Timestamp.  # noqa: E501


        :return: The seconds of this Timestamp.  # noqa: E501
        :rtype: int
        """
        return self._seconds

    @seconds.setter
    def seconds(self, seconds):
        """Sets the seconds of this Timestamp.


        :param seconds: The seconds of this Timestamp.  # noqa: E501
        :type: int
        """

        self._seconds = seconds

    @property
    def time(self):
        """Gets the time of this Timestamp.  # noqa: E501


        :return: The time of this Timestamp.  # noqa: E501
        :rtype: int
        """
        return self._time

    @time.setter
    def time(self, time):
        """Sets the time of this Timestamp.


        :param time: The time of this Timestamp.  # noqa: E501
        :type: int
        """

        self._time = time

    @property
    def timezone_offset(self):
        """Gets the timezone_offset of this Timestamp.  # noqa: E501


        :return: The timezone_offset of this Timestamp.  # noqa: E501
        :rtype: int
        """
        return self._timezone_offset

    @timezone_offset.setter
    def timezone_offset(self, timezone_offset):
        """Sets the timezone_offset of this Timestamp.


        :param timezone_offset: The timezone_offset of this Timestamp.  # noqa: E501
        :type: int
        """

        self._timezone_offset = timezone_offset

    @property
    def year(self):
        """Gets the year of this Timestamp.  # noqa: E501


        :return: The year of this Timestamp.  # noqa: E501
        :rtype: int
        """
        return self._year

    @year.setter
    def year(self, year):
        """Sets the year of this Timestamp.


        :param year: The year of this Timestamp.  # noqa: E501
        :type: int
        """

        self._year = year

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Timestamp, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Timestamp):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Kodexa

    Content Intelligence  # noqa: E501

    OpenAPI spec version: 2.0.132
    Contact: suppot@kodexa.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class OrganizationDashboard(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'pipeline_count': 'int',
        'request_count': 'int',
        'service_count': 'int',
        'user_count': 'int'
    }

    attribute_map = {
        'pipeline_count': 'pipelineCount',
        'request_count': 'requestCount',
        'service_count': 'serviceCount',
        'user_count': 'userCount'
    }

    def __init__(self, pipeline_count=None, request_count=None, service_count=None, user_count=None):  # noqa: E501
        """OrganizationDashboard - a model defined in Swagger"""  # noqa: E501
        self._pipeline_count = None
        self._request_count = None
        self._service_count = None
        self._user_count = None
        self.discriminator = None
        if pipeline_count is not None:
            self.pipeline_count = pipeline_count
        if request_count is not None:
            self.request_count = request_count
        if service_count is not None:
            self.service_count = service_count
        if user_count is not None:
            self.user_count = user_count

    @property
    def pipeline_count(self):
        """Gets the pipeline_count of this OrganizationDashboard.  # noqa: E501


        :return: The pipeline_count of this OrganizationDashboard.  # noqa: E501
        :rtype: int
        """
        return self._pipeline_count

    @pipeline_count.setter
    def pipeline_count(self, pipeline_count):
        """Sets the pipeline_count of this OrganizationDashboard.


        :param pipeline_count: The pipeline_count of this OrganizationDashboard.  # noqa: E501
        :type: int
        """

        self._pipeline_count = pipeline_count

    @property
    def request_count(self):
        """Gets the request_count of this OrganizationDashboard.  # noqa: E501


        :return: The request_count of this OrganizationDashboard.  # noqa: E501
        :rtype: int
        """
        return self._request_count

    @request_count.setter
    def request_count(self, request_count):
        """Sets the request_count of this OrganizationDashboard.


        :param request_count: The request_count of this OrganizationDashboard.  # noqa: E501
        :type: int
        """

        self._request_count = request_count

    @property
    def service_count(self):
        """Gets the service_count of this OrganizationDashboard.  # noqa: E501


        :return: The service_count of this OrganizationDashboard.  # noqa: E501
        :rtype: int
        """
        return self._service_count

    @service_count.setter
    def service_count(self, service_count):
        """Sets the service_count of this OrganizationDashboard.


        :param service_count: The service_count of this OrganizationDashboard.  # noqa: E501
        :type: int
        """

        self._service_count = service_count

    @property
    def user_count(self):
        """Gets the user_count of this OrganizationDashboard.  # noqa: E501


        :return: The user_count of this OrganizationDashboard.  # noqa: E501
        :rtype: int
        """
        return self._user_count

    @user_count.setter
    def user_count(self, user_count):
        """Sets the user_count of this OrganizationDashboard.


        :param user_count: The user_count of this OrganizationDashboard.  # noqa: E501
        :type: int
        """

        self._user_count = user_count

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(OrganizationDashboard, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OrganizationDashboard):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Kodexa

    Content Intelligence  # noqa: E501

    OpenAPI spec version: 2.0.132
    Contact: suppot@kodexa.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class CloudPipeline(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'exceptions': 'list[ExceptionDetails]',
        'id': 'str',
        'ref': 'str',
        'steps': 'list[CloudExecutionStep]',
        'valid': 'bool'
    }

    attribute_map = {
        'exceptions': 'exceptions',
        'id': 'id',
        'ref': 'ref',
        'steps': 'steps',
        'valid': 'valid'
    }

    def __init__(self, exceptions=None, id=None, ref=None, steps=None, valid=None):  # noqa: E501
        """CloudPipeline - a model defined in Swagger"""  # noqa: E501
        self._exceptions = None
        self._id = None
        self._ref = None
        self._steps = None
        self._valid = None
        self.discriminator = None
        if exceptions is not None:
            self.exceptions = exceptions
        if id is not None:
            self.id = id
        if ref is not None:
            self.ref = ref
        if steps is not None:
            self.steps = steps
        if valid is not None:
            self.valid = valid

    @property
    def exceptions(self):
        """Gets the exceptions of this CloudPipeline.  # noqa: E501


        :return: The exceptions of this CloudPipeline.  # noqa: E501
        :rtype: list[ExceptionDetails]
        """
        return self._exceptions

    @exceptions.setter
    def exceptions(self, exceptions):
        """Sets the exceptions of this CloudPipeline.


        :param exceptions: The exceptions of this CloudPipeline.  # noqa: E501
        :type: list[ExceptionDetails]
        """

        self._exceptions = exceptions

    @property
    def id(self):
        """Gets the id of this CloudPipeline.  # noqa: E501


        :return: The id of this CloudPipeline.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this CloudPipeline.


        :param id: The id of this CloudPipeline.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def ref(self):
        """Gets the ref of this CloudPipeline.  # noqa: E501


        :return: The ref of this CloudPipeline.  # noqa: E501
        :rtype: str
        """
        return self._ref

    @ref.setter
    def ref(self, ref):
        """Sets the ref of this CloudPipeline.


        :param ref: The ref of this CloudPipeline.  # noqa: E501
        :type: str
        """

        self._ref = ref

    @property
    def steps(self):
        """Gets the steps of this CloudPipeline.  # noqa: E501


        :return: The steps of this CloudPipeline.  # noqa: E501
        :rtype: list[CloudExecutionStep]
        """
        return self._steps

    @steps.setter
    def steps(self, steps):
        """Sets the steps of this CloudPipeline.


        :param steps: The steps of this CloudPipeline.  # noqa: E501
        :type: list[CloudExecutionStep]
        """

        self._steps = steps

    @property
    def valid(self):
        """Gets the valid of this CloudPipeline.  # noqa: E501


        :return: The valid of this CloudPipeline.  # noqa: E501
        :rtype: bool
        """
        return self._valid

    @valid.setter
    def valid(self, valid):
        """Sets the valid of this CloudPipeline.


        :param valid: The valid of this CloudPipeline.  # noqa: E501
        :type: bool
        """

        self._valid = valid

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CloudPipeline, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CloudPipeline):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Kodexa

    Content Intelligence  # noqa: E501

    OpenAPI spec version: 2.0.132
    Contact: suppot@kodexa.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from kodexa_cloud.api_client import ApiClient


class AccountControllerApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def activate_user_using_get(self, activation_token, **kwargs):  # noqa: E501
        """activateUser  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.activate_user_using_get(activation_token, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str activation_token: activationToken (required)
        :return: UserActivation
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.activate_user_using_get_with_http_info(activation_token, **kwargs)  # noqa: E501
        else:
            (data) = self.activate_user_using_get_with_http_info(activation_token, **kwargs)  # noqa: E501
            return data

    def activate_user_using_get_with_http_info(self, activation_token, **kwargs):  # noqa: E501
        """activateUser  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.activate_user_using_get_with_http_info(activation_token, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str activation_token: activationToken (required)
        :return: UserActivation
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['activation_token']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method activate_user_using_get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'activation_token' is set
        if ('activation_token' not in params or
                params['activation_token'] is None):
            raise ValueError("Missing the required parameter `activation_token` when calling `activate_user_using_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'activation_token' in params:
            path_params['activationToken'] = params['activation_token']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/api/account/activation/{activationToken}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='UserActivation',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def activate_user_using_put(self, body, activation_token, **kwargs):  # noqa: E501
        """activateUser  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.activate_user_using_put(body, activation_token, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param UserActivation body: userActivation (required)
        :param str activation_token: activationToken (required)
        :return: UserActivation
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.activate_user_using_put_with_http_info(body, activation_token, **kwargs)  # noqa: E501
        else:
            (data) = self.activate_user_using_put_with_http_info(body, activation_token, **kwargs)  # noqa: E501
            return data

    def activate_user_using_put_with_http_info(self, body, activation_token, **kwargs):  # noqa: E501
        """activateUser  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.activate_user_using_put_with_http_info(body, activation_token, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param UserActivation body: userActivation (required)
        :param str activation_token: activationToken (required)
        :return: UserActivation
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'activation_token']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method activate_user_using_put" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `activate_user_using_put`")  # noqa: E501
        # verify the required parameter 'activation_token' is set
        if ('activation_token' not in params or
                params['activation_token'] is None):
            raise ValueError("Missing the required parameter `activation_token` when calling `activate_user_using_put`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'activation_token' in params:
            path_params['activationToken'] = params['activation_token']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/api/account/activation/{activationToken}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='UserActivation',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def authenticate_user_using_post(self, body, **kwargs):  # noqa: E501
        """authenticateUser  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.authenticate_user_using_post(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param LoginRequest body: loginRequest (required)
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.authenticate_user_using_post_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.authenticate_user_using_post_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def authenticate_user_using_post_with_http_info(self, body, **kwargs):  # noqa: E501
        """authenticateUser  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.authenticate_user_using_post_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param LoginRequest body: loginRequest (required)
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method authenticate_user_using_post" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `authenticate_user_using_post`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/api/account/signin', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_me_using_get(self, **kwargs):  # noqa: E501
        """getMe  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_me_using_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: PlatformUser
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_me_using_get_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_me_using_get_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_me_using_get_with_http_info(self, **kwargs):  # noqa: E501
        """getMe  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_me_using_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: PlatformUser
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_me_using_get" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/api/account/me', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PlatformUser',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_memberships_using_get(self, **kwargs):  # noqa: E501
        """getMemberships  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_memberships_using_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: list[Membership]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_memberships_using_get_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_memberships_using_get_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_memberships_using_get_with_http_info(self, **kwargs):  # noqa: E501
        """getMemberships  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_memberships_using_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: list[Membership]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_memberships_using_get" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/api/account/memberships', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[Membership]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def lookup_using_get(self, email, **kwargs):  # noqa: E501
        """lookup  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.lookup_using_get(email, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str email: email (required)
        :return: EmailLookup
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.lookup_using_get_with_http_info(email, **kwargs)  # noqa: E501
        else:
            (data) = self.lookup_using_get_with_http_info(email, **kwargs)  # noqa: E501
            return data

    def lookup_using_get_with_http_info(self, email, **kwargs):  # noqa: E501
        """lookup  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.lookup_using_get_with_http_info(email, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str email: email (required)
        :return: EmailLookup
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['email']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method lookup_using_get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'email' is set
        if ('email' not in params or
                params['email'] is None):
            raise ValueError("Missing the required parameter `email` when calling `lookup_using_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'email' in params:
            query_params.append(('email', params['email']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/api/account/lookup', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='EmailLookup',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def password_change_using_delete(self, body, **kwargs):  # noqa: E501
        """passwordChange  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.password_change_using_delete(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param PasswordChange body: passwordChange (required)
        :return: PlatformUser
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.password_change_using_delete_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.password_change_using_delete_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def password_change_using_delete_with_http_info(self, body, **kwargs):  # noqa: E501
        """passwordChange  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.password_change_using_delete_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param PasswordChange body: passwordChange (required)
        :return: PlatformUser
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method password_change_using_delete" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `password_change_using_delete`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/api/account/passwordChange', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PlatformUser',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def password_change_using_get(self, body, **kwargs):  # noqa: E501
        """passwordChange  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.password_change_using_get(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param PasswordChange body: passwordChange (required)
        :return: PlatformUser
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.password_change_using_get_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.password_change_using_get_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def password_change_using_get_with_http_info(self, body, **kwargs):  # noqa: E501
        """passwordChange  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.password_change_using_get_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param PasswordChange body: passwordChange (required)
        :return: PlatformUser
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method password_change_using_get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `password_change_using_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/api/account/passwordChange', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PlatformUser',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def password_change_using_head(self, body, **kwargs):  # noqa: E501
        """passwordChange  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.password_change_using_head(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param PasswordChange body: passwordChange (required)
        :return: PlatformUser
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.password_change_using_head_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.password_change_using_head_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def password_change_using_head_with_http_info(self, body, **kwargs):  # noqa: E501
        """passwordChange  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.password_change_using_head_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param PasswordChange body: passwordChange (required)
        :return: PlatformUser
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method password_change_using_head" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `password_change_using_head`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/api/account/passwordChange', 'HEAD',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PlatformUser',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def password_change_using_options(self, body, **kwargs):  # noqa: E501
        """passwordChange  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.password_change_using_options(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param PasswordChange body: passwordChange (required)
        :return: PlatformUser
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.password_change_using_options_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.password_change_using_options_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def password_change_using_options_with_http_info(self, body, **kwargs):  # noqa: E501
        """passwordChange  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.password_change_using_options_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param PasswordChange body: passwordChange (required)
        :return: PlatformUser
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method password_change_using_options" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `password_change_using_options`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/api/account/passwordChange', 'OPTIONS',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PlatformUser',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def password_change_using_patch(self, body, **kwargs):  # noqa: E501
        """passwordChange  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.password_change_using_patch(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param PasswordChange body: passwordChange (required)
        :return: PlatformUser
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.password_change_using_patch_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.password_change_using_patch_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def password_change_using_patch_with_http_info(self, body, **kwargs):  # noqa: E501
        """passwordChange  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.password_change_using_patch_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param PasswordChange body: passwordChange (required)
        :return: PlatformUser
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method password_change_using_patch" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `password_change_using_patch`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/api/account/passwordChange', 'PATCH',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PlatformUser',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def password_change_using_post(self, body, **kwargs):  # noqa: E501
        """passwordChange  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.password_change_using_post(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param PasswordChange body: passwordChange (required)
        :return: PlatformUser
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.password_change_using_post_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.password_change_using_post_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def password_change_using_post_with_http_info(self, body, **kwargs):  # noqa: E501
        """passwordChange  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.password_change_using_post_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param PasswordChange body: passwordChange (required)
        :return: PlatformUser
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method password_change_using_post" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `password_change_using_post`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/api/account/passwordChange', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PlatformUser',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def password_change_using_put(self, body, **kwargs):  # noqa: E501
        """passwordChange  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.password_change_using_put(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param PasswordChange body: passwordChange (required)
        :return: PlatformUser
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.password_change_using_put_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.password_change_using_put_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def password_change_using_put_with_http_info(self, body, **kwargs):  # noqa: E501
        """passwordChange  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.password_change_using_put_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param PasswordChange body: passwordChange (required)
        :return: PlatformUser
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method password_change_using_put" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `password_change_using_put`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/api/account/passwordChange', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PlatformUser',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def register_user_using_delete(self, body, **kwargs):  # noqa: E501
        """registerUser  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.register_user_using_delete(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param RegisterUser body: registerUser (required)
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.register_user_using_delete_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.register_user_using_delete_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def register_user_using_delete_with_http_info(self, body, **kwargs):  # noqa: E501
        """registerUser  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.register_user_using_delete_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param RegisterUser body: registerUser (required)
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method register_user_using_delete" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `register_user_using_delete`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/api/account/register', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def register_user_using_get(self, body, **kwargs):  # noqa: E501
        """registerUser  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.register_user_using_get(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param RegisterUser body: registerUser (required)
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.register_user_using_get_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.register_user_using_get_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def register_user_using_get_with_http_info(self, body, **kwargs):  # noqa: E501
        """registerUser  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.register_user_using_get_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param RegisterUser body: registerUser (required)
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method register_user_using_get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `register_user_using_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/api/account/register', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def register_user_using_head(self, body, **kwargs):  # noqa: E501
        """registerUser  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.register_user_using_head(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param RegisterUser body: registerUser (required)
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.register_user_using_head_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.register_user_using_head_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def register_user_using_head_with_http_info(self, body, **kwargs):  # noqa: E501
        """registerUser  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.register_user_using_head_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param RegisterUser body: registerUser (required)
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method register_user_using_head" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `register_user_using_head`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/api/account/register', 'HEAD',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def register_user_using_options(self, body, **kwargs):  # noqa: E501
        """registerUser  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.register_user_using_options(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param RegisterUser body: registerUser (required)
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.register_user_using_options_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.register_user_using_options_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def register_user_using_options_with_http_info(self, body, **kwargs):  # noqa: E501
        """registerUser  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.register_user_using_options_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param RegisterUser body: registerUser (required)
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method register_user_using_options" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `register_user_using_options`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/api/account/register', 'OPTIONS',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def register_user_using_patch(self, body, **kwargs):  # noqa: E501
        """registerUser  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.register_user_using_patch(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param RegisterUser body: registerUser (required)
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.register_user_using_patch_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.register_user_using_patch_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def register_user_using_patch_with_http_info(self, body, **kwargs):  # noqa: E501
        """registerUser  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.register_user_using_patch_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param RegisterUser body: registerUser (required)
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method register_user_using_patch" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `register_user_using_patch`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/api/account/register', 'PATCH',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def register_user_using_post(self, body, **kwargs):  # noqa: E501
        """registerUser  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.register_user_using_post(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param RegisterUser body: registerUser (required)
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.register_user_using_post_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.register_user_using_post_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def register_user_using_post_with_http_info(self, body, **kwargs):  # noqa: E501
        """registerUser  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.register_user_using_post_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param RegisterUser body: registerUser (required)
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method register_user_using_post" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `register_user_using_post`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/api/account/register', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def register_user_using_put(self, body, **kwargs):  # noqa: E501
        """registerUser  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.register_user_using_put(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param RegisterUser body: registerUser (required)
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.register_user_using_put_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.register_user_using_put_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def register_user_using_put_with_http_info(self, body, **kwargs):  # noqa: E501
        """registerUser  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.register_user_using_put_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param RegisterUser body: registerUser (required)
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method register_user_using_put" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `register_user_using_put`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/api/account/register', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_me_using_put(self, body, **kwargs):  # noqa: E501
        """updateMe  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_me_using_put(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param PlatformUser body: updatedUser (required)
        :return: PlatformUser
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_me_using_put_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.update_me_using_put_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def update_me_using_put_with_http_info(self, body, **kwargs):  # noqa: E501
        """updateMe  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_me_using_put_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param PlatformUser body: updatedUser (required)
        :return: PlatformUser
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_me_using_put" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `update_me_using_put`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/api/account/me', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PlatformUser',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Kodexa

    Content Intelligence  # noqa: E501

    OpenAPI spec version: 2.0.132
    Contact: suppot@kodexa.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class PlatformOverview(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'build_time': 'str',
        'commit_id': 'str',
        'dsn': 'str',
        'environment': 'str',
        'host_name': 'str',
        'name': 'str',
        'release': 'str',
        'version': 'str'
    }

    attribute_map = {
        'build_time': 'buildTime',
        'commit_id': 'commitId',
        'dsn': 'dsn',
        'environment': 'environment',
        'host_name': 'hostName',
        'name': 'name',
        'release': 'release',
        'version': 'version'
    }

    def __init__(self, build_time=None, commit_id=None, dsn=None, environment=None, host_name=None, name=None, release=None, version=None):  # noqa: E501
        """PlatformOverview - a model defined in Swagger"""  # noqa: E501
        self._build_time = None
        self._commit_id = None
        self._dsn = None
        self._environment = None
        self._host_name = None
        self._name = None
        self._release = None
        self._version = None
        self.discriminator = None
        if build_time is not None:
            self.build_time = build_time
        if commit_id is not None:
            self.commit_id = commit_id
        if dsn is not None:
            self.dsn = dsn
        if environment is not None:
            self.environment = environment
        if host_name is not None:
            self.host_name = host_name
        if name is not None:
            self.name = name
        if release is not None:
            self.release = release
        if version is not None:
            self.version = version

    @property
    def build_time(self):
        """Gets the build_time of this PlatformOverview.  # noqa: E501


        :return: The build_time of this PlatformOverview.  # noqa: E501
        :rtype: str
        """
        return self._build_time

    @build_time.setter
    def build_time(self, build_time):
        """Sets the build_time of this PlatformOverview.


        :param build_time: The build_time of this PlatformOverview.  # noqa: E501
        :type: str
        """

        self._build_time = build_time

    @property
    def commit_id(self):
        """Gets the commit_id of this PlatformOverview.  # noqa: E501


        :return: The commit_id of this PlatformOverview.  # noqa: E501
        :rtype: str
        """
        return self._commit_id

    @commit_id.setter
    def commit_id(self, commit_id):
        """Sets the commit_id of this PlatformOverview.


        :param commit_id: The commit_id of this PlatformOverview.  # noqa: E501
        :type: str
        """

        self._commit_id = commit_id

    @property
    def dsn(self):
        """Gets the dsn of this PlatformOverview.  # noqa: E501


        :return: The dsn of this PlatformOverview.  # noqa: E501
        :rtype: str
        """
        return self._dsn

    @dsn.setter
    def dsn(self, dsn):
        """Sets the dsn of this PlatformOverview.


        :param dsn: The dsn of this PlatformOverview.  # noqa: E501
        :type: str
        """

        self._dsn = dsn

    @property
    def environment(self):
        """Gets the environment of this PlatformOverview.  # noqa: E501


        :return: The environment of this PlatformOverview.  # noqa: E501
        :rtype: str
        """
        return self._environment

    @environment.setter
    def environment(self, environment):
        """Sets the environment of this PlatformOverview.


        :param environment: The environment of this PlatformOverview.  # noqa: E501
        :type: str
        """

        self._environment = environment

    @property
    def host_name(self):
        """Gets the host_name of this PlatformOverview.  # noqa: E501


        :return: The host_name of this PlatformOverview.  # noqa: E501
        :rtype: str
        """
        return self._host_name

    @host_name.setter
    def host_name(self, host_name):
        """Sets the host_name of this PlatformOverview.


        :param host_name: The host_name of this PlatformOverview.  # noqa: E501
        :type: str
        """

        self._host_name = host_name

    @property
    def name(self):
        """Gets the name of this PlatformOverview.  # noqa: E501


        :return: The name of this PlatformOverview.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this PlatformOverview.


        :param name: The name of this PlatformOverview.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def release(self):
        """Gets the release of this PlatformOverview.  # noqa: E501


        :return: The release of this PlatformOverview.  # noqa: E501
        :rtype: str
        """
        return self._release

    @release.setter
    def release(self, release):
        """Sets the release of this PlatformOverview.


        :param release: The release of this PlatformOverview.  # noqa: E501
        :type: str
        """

        self._release = release

    @property
    def version(self):
        """Gets the version of this PlatformOverview.  # noqa: E501


        :return: The version of this PlatformOverview.  # noqa: E501
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this PlatformOverview.


        :param version: The version of this PlatformOverview.  # noqa: E501
        :type: str
        """

        self._version = version

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(PlatformOverview, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PlatformOverview):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Kodexa

    Content Intelligence  # noqa: E501

    OpenAPI spec version: 2.0.132
    Contact: suppot@kodexa.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class ModelAndView(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'empty': 'bool',
        'model': 'object',
        'model_map': 'dict(str, object)',
        'reference': 'bool',
        'status': 'str',
        'view': 'View',
        'view_name': 'str'
    }

    attribute_map = {
        'empty': 'empty',
        'model': 'model',
        'model_map': 'modelMap',
        'reference': 'reference',
        'status': 'status',
        'view': 'view',
        'view_name': 'viewName'
    }

    def __init__(self, empty=None, model=None, model_map=None, reference=None, status=None, view=None, view_name=None):  # noqa: E501
        """ModelAndView - a model defined in Swagger"""  # noqa: E501
        self._empty = None
        self._model = None
        self._model_map = None
        self._reference = None
        self._status = None
        self._view = None
        self._view_name = None
        self.discriminator = None
        if empty is not None:
            self.empty = empty
        if model is not None:
            self.model = model
        if model_map is not None:
            self.model_map = model_map
        if reference is not None:
            self.reference = reference
        if status is not None:
            self.status = status
        if view is not None:
            self.view = view
        if view_name is not None:
            self.view_name = view_name

    @property
    def empty(self):
        """Gets the empty of this ModelAndView.  # noqa: E501


        :return: The empty of this ModelAndView.  # noqa: E501
        :rtype: bool
        """
        return self._empty

    @empty.setter
    def empty(self, empty):
        """Sets the empty of this ModelAndView.


        :param empty: The empty of this ModelAndView.  # noqa: E501
        :type: bool
        """

        self._empty = empty

    @property
    def model(self):
        """Gets the model of this ModelAndView.  # noqa: E501


        :return: The model of this ModelAndView.  # noqa: E501
        :rtype: object
        """
        return self._model

    @model.setter
    def model(self, model):
        """Sets the model of this ModelAndView.


        :param model: The model of this ModelAndView.  # noqa: E501
        :type: object
        """

        self._model = model

    @property
    def model_map(self):
        """Gets the model_map of this ModelAndView.  # noqa: E501


        :return: The model_map of this ModelAndView.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._model_map

    @model_map.setter
    def model_map(self, model_map):
        """Sets the model_map of this ModelAndView.


        :param model_map: The model_map of this ModelAndView.  # noqa: E501
        :type: dict(str, object)
        """

        self._model_map = model_map

    @property
    def reference(self):
        """Gets the reference of this ModelAndView.  # noqa: E501


        :return: The reference of this ModelAndView.  # noqa: E501
        :rtype: bool
        """
        return self._reference

    @reference.setter
    def reference(self, reference):
        """Sets the reference of this ModelAndView.


        :param reference: The reference of this ModelAndView.  # noqa: E501
        :type: bool
        """

        self._reference = reference

    @property
    def status(self):
        """Gets the status of this ModelAndView.  # noqa: E501


        :return: The status of this ModelAndView.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this ModelAndView.


        :param status: The status of this ModelAndView.  # noqa: E501
        :type: str
        """
        allowed_values = ["100 CONTINUE", "101 SWITCHING_PROTOCOLS", "102 PROCESSING", "103 CHECKPOINT", "200 OK", "201 CREATED", "202 ACCEPTED", "203 NON_AUTHORITATIVE_INFORMATION", "204 NO_CONTENT", "205 RESET_CONTENT", "206 PARTIAL_CONTENT", "207 MULTI_STATUS", "208 ALREADY_REPORTED", "226 IM_USED", "300 MULTIPLE_CHOICES", "301 MOVED_PERMANENTLY", "302 FOUND", "302 MOVED_TEMPORARILY", "303 SEE_OTHER", "304 NOT_MODIFIED", "305 USE_PROXY", "307 TEMPORARY_REDIRECT", "308 PERMANENT_REDIRECT", "400 BAD_REQUEST", "401 UNAUTHORIZED", "402 PAYMENT_REQUIRED", "403 FORBIDDEN", "404 NOT_FOUND", "405 METHOD_NOT_ALLOWED", "406 NOT_ACCEPTABLE", "407 PROXY_AUTHENTICATION_REQUIRED", "408 REQUEST_TIMEOUT", "409 CONFLICT", "410 GONE", "411 LENGTH_REQUIRED", "412 PRECONDITION_FAILED", "413 PAYLOAD_TOO_LARGE", "413 REQUEST_ENTITY_TOO_LARGE", "414 URI_TOO_LONG", "414 REQUEST_URI_TOO_LONG", "415 UNSUPPORTED_MEDIA_TYPE", "416 REQUESTED_RANGE_NOT_SATISFIABLE", "417 EXPECTATION_FAILED", "418 I_AM_A_TEAPOT", "419 INSUFFICIENT_SPACE_ON_RESOURCE", "420 METHOD_FAILURE", "421 DESTINATION_LOCKED", "422 UNPROCESSABLE_ENTITY", "423 LOCKED", "424 FAILED_DEPENDENCY", "425 TOO_EARLY", "426 UPGRADE_REQUIRED", "428 PRECONDITION_REQUIRED", "429 TOO_MANY_REQUESTS", "431 REQUEST_HEADER_FIELDS_TOO_LARGE", "451 UNAVAILABLE_FOR_LEGAL_REASONS", "500 INTERNAL_SERVER_ERROR", "501 NOT_IMPLEMENTED", "502 BAD_GATEWAY", "503 SERVICE_UNAVAILABLE", "504 GATEWAY_TIMEOUT", "505 HTTP_VERSION_NOT_SUPPORTED", "506 VARIANT_ALSO_NEGOTIATES", "507 INSUFFICIENT_STORAGE", "508 LOOP_DETECTED", "509 BANDWIDTH_LIMIT_EXCEEDED", "510 NOT_EXTENDED", "511 NETWORK_AUTHENTICATION_REQUIRED"]  # noqa: E501
        if status not in allowed_values:
            raise ValueError(
                "Invalid value for `status` ({0}), must be one of {1}"  # noqa: E501
                .format(status, allowed_values)
            )

        self._status = status

    @property
    def view(self):
        """Gets the view of this ModelAndView.  # noqa: E501


        :return: The view of this ModelAndView.  # noqa: E501
        :rtype: View
        """
        return self._view

    @view.setter
    def view(self, view):
        """Sets the view of this ModelAndView.


        :param view: The view of this ModelAndView.  # noqa: E501
        :type: View
        """

        self._view = view

    @property
    def view_name(self):
        """Gets the view_name of this ModelAndView.  # noqa: E501


        :return: The view_name of this ModelAndView.  # noqa: E501
        :rtype: str
        """
        return self._view_name

    @view_name.setter
    def view_name(self, view_name):
        """Sets the view_name of this ModelAndView.


        :param view_name: The view_name of this ModelAndView.  # noqa: E501
        :type: str
        """

        self._view_name = view_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ModelAndView, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ModelAndView):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Kodexa

    Content Intelligence  # noqa: E501

    OpenAPI spec version: 2.0.132
    Contact: suppot@kodexa.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class BotMetadata(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'create_session': 'bool',
        'graph_cells': 'list[GraphCell]',
        'triggers': 'list[BotEventTrigger]'
    }

    attribute_map = {
        'create_session': 'createSession',
        'graph_cells': 'graphCells',
        'triggers': 'triggers'
    }

    def __init__(self, create_session=None, graph_cells=None, triggers=None):  # noqa: E501
        """BotMetadata - a model defined in Swagger"""  # noqa: E501
        self._create_session = None
        self._graph_cells = None
        self._triggers = None
        self.discriminator = None
        if create_session is not None:
            self.create_session = create_session
        if graph_cells is not None:
            self.graph_cells = graph_cells
        if triggers is not None:
            self.triggers = triggers

    @property
    def create_session(self):
        """Gets the create_session of this BotMetadata.  # noqa: E501


        :return: The create_session of this BotMetadata.  # noqa: E501
        :rtype: bool
        """
        return self._create_session

    @create_session.setter
    def create_session(self, create_session):
        """Sets the create_session of this BotMetadata.


        :param create_session: The create_session of this BotMetadata.  # noqa: E501
        :type: bool
        """

        self._create_session = create_session

    @property
    def graph_cells(self):
        """Gets the graph_cells of this BotMetadata.  # noqa: E501


        :return: The graph_cells of this BotMetadata.  # noqa: E501
        :rtype: list[GraphCell]
        """
        return self._graph_cells

    @graph_cells.setter
    def graph_cells(self, graph_cells):
        """Sets the graph_cells of this BotMetadata.


        :param graph_cells: The graph_cells of this BotMetadata.  # noqa: E501
        :type: list[GraphCell]
        """

        self._graph_cells = graph_cells

    @property
    def triggers(self):
        """Gets the triggers of this BotMetadata.  # noqa: E501


        :return: The triggers of this BotMetadata.  # noqa: E501
        :rtype: list[BotEventTrigger]
        """
        return self._triggers

    @triggers.setter
    def triggers(self, triggers):
        """Sets the triggers of this BotMetadata.


        :param triggers: The triggers of this BotMetadata.  # noqa: E501
        :type: list[BotEventTrigger]
        """

        self._triggers = triggers

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(BotMetadata, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BotMetadata):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Kodexa

    Content Intelligence  # noqa: E501

    OpenAPI spec version: 2.0.132
    Contact: suppot@kodexa.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class PageOfContentService(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'content': 'list[ContentService]',
        'empty': 'bool',
        'first': 'bool',
        'last': 'bool',
        'number': 'int',
        'number_of_elements': 'int',
        'pageable': 'Pageable',
        'size': 'int',
        'sort': 'Sort',
        'total_elements': 'int',
        'total_pages': 'int'
    }

    attribute_map = {
        'content': 'content',
        'empty': 'empty',
        'first': 'first',
        'last': 'last',
        'number': 'number',
        'number_of_elements': 'numberOfElements',
        'pageable': 'pageable',
        'size': 'size',
        'sort': 'sort',
        'total_elements': 'totalElements',
        'total_pages': 'totalPages'
    }

    def __init__(self, content=None, empty=None, first=None, last=None, number=None, number_of_elements=None, pageable=None, size=None, sort=None, total_elements=None, total_pages=None):  # noqa: E501
        """PageOfContentService - a model defined in Swagger"""  # noqa: E501
        self._content = None
        self._empty = None
        self._first = None
        self._last = None
        self._number = None
        self._number_of_elements = None
        self._pageable = None
        self._size = None
        self._sort = None
        self._total_elements = None
        self._total_pages = None
        self.discriminator = None
        if content is not None:
            self.content = content
        if empty is not None:
            self.empty = empty
        if first is not None:
            self.first = first
        if last is not None:
            self.last = last
        if number is not None:
            self.number = number
        if number_of_elements is not None:
            self.number_of_elements = number_of_elements
        if pageable is not None:
            self.pageable = pageable
        if size is not None:
            self.size = size
        if sort is not None:
            self.sort = sort
        if total_elements is not None:
            self.total_elements = total_elements
        if total_pages is not None:
            self.total_pages = total_pages

    @property
    def content(self):
        """Gets the content of this PageOfContentService.  # noqa: E501


        :return: The content of this PageOfContentService.  # noqa: E501
        :rtype: list[ContentService]
        """
        return self._content

    @content.setter
    def content(self, content):
        """Sets the content of this PageOfContentService.


        :param content: The content of this PageOfContentService.  # noqa: E501
        :type: list[ContentService]
        """

        self._content = content

    @property
    def empty(self):
        """Gets the empty of this PageOfContentService.  # noqa: E501


        :return: The empty of this PageOfContentService.  # noqa: E501
        :rtype: bool
        """
        return self._empty

    @empty.setter
    def empty(self, empty):
        """Sets the empty of this PageOfContentService.


        :param empty: The empty of this PageOfContentService.  # noqa: E501
        :type: bool
        """

        self._empty = empty

    @property
    def first(self):
        """Gets the first of this PageOfContentService.  # noqa: E501


        :return: The first of this PageOfContentService.  # noqa: E501
        :rtype: bool
        """
        return self._first

    @first.setter
    def first(self, first):
        """Sets the first of this PageOfContentService.


        :param first: The first of this PageOfContentService.  # noqa: E501
        :type: bool
        """

        self._first = first

    @property
    def last(self):
        """Gets the last of this PageOfContentService.  # noqa: E501


        :return: The last of this PageOfContentService.  # noqa: E501
        :rtype: bool
        """
        return self._last

    @last.setter
    def last(self, last):
        """Sets the last of this PageOfContentService.


        :param last: The last of this PageOfContentService.  # noqa: E501
        :type: bool
        """

        self._last = last

    @property
    def number(self):
        """Gets the number of this PageOfContentService.  # noqa: E501


        :return: The number of this PageOfContentService.  # noqa: E501
        :rtype: int
        """
        return self._number

    @number.setter
    def number(self, number):
        """Sets the number of this PageOfContentService.


        :param number: The number of this PageOfContentService.  # noqa: E501
        :type: int
        """

        self._number = number

    @property
    def number_of_elements(self):
        """Gets the number_of_elements of this PageOfContentService.  # noqa: E501


        :return: The number_of_elements of this PageOfContentService.  # noqa: E501
        :rtype: int
        """
        return self._number_of_elements

    @number_of_elements.setter
    def number_of_elements(self, number_of_elements):
        """Sets the number_of_elements of this PageOfContentService.


        :param number_of_elements: The number_of_elements of this PageOfContentService.  # noqa: E501
        :type: int
        """

        self._number_of_elements = number_of_elements

    @property
    def pageable(self):
        """Gets the pageable of this PageOfContentService.  # noqa: E501


        :return: The pageable of this PageOfContentService.  # noqa: E501
        :rtype: Pageable
        """
        return self._pageable

    @pageable.setter
    def pageable(self, pageable):
        """Sets the pageable of this PageOfContentService.


        :param pageable: The pageable of this PageOfContentService.  # noqa: E501
        :type: Pageable
        """

        self._pageable = pageable

    @property
    def size(self):
        """Gets the size of this PageOfContentService.  # noqa: E501


        :return: The size of this PageOfContentService.  # noqa: E501
        :rtype: int
        """
        return self._size

    @size.setter
    def size(self, size):
        """Sets the size of this PageOfContentService.


        :param size: The size of this PageOfContentService.  # noqa: E501
        :type: int
        """

        self._size = size

    @property
    def sort(self):
        """Gets the sort of this PageOfContentService.  # noqa: E501


        :return: The sort of this PageOfContentService.  # noqa: E501
        :rtype: Sort
        """
        return self._sort

    @sort.setter
    def sort(self, sort):
        """Sets the sort of this PageOfContentService.


        :param sort: The sort of this PageOfContentService.  # noqa: E501
        :type: Sort
        """

        self._sort = sort

    @property
    def total_elements(self):
        """Gets the total_elements of this PageOfContentService.  # noqa: E501


        :return: The total_elements of this PageOfContentService.  # noqa: E501
        :rtype: int
        """
        return self._total_elements

    @total_elements.setter
    def total_elements(self, total_elements):
        """Sets the total_elements of this PageOfContentService.


        :param total_elements: The total_elements of this PageOfContentService.  # noqa: E501
        :type: int
        """

        self._total_elements = total_elements

    @property
    def total_pages(self):
        """Gets the total_pages of this PageOfContentService.  # noqa: E501


        :return: The total_pages of this PageOfContentService.  # noqa: E501
        :rtype: int
        """
        return self._total_pages

    @total_pages.setter
    def total_pages(self, total_pages):
        """Sets the total_pages of this PageOfContentService.


        :param total_pages: The total_pages of this PageOfContentService.  # noqa: E501
        :type: int
        """

        self._total_pages = total_pages

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(PageOfContentService, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PageOfContentService):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Kodexa

    Content Intelligence  # noqa: E501

    OpenAPI spec version: 2.0.132
    Contact: suppot@kodexa.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class CloudExecutionStep(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'content_service_reference': 'ContentServiceReference',
        'context': 'object',
        'document_references': 'list[CloudDocumentReference]',
        'end': 'datetime',
        'exception_details': 'ExceptionDetails',
        'file_references': 'list[CloudFileReference]',
        'id': 'str',
        'options': 'object',
        'processing_time': 'int',
        'start': 'datetime',
        'status': 'str',
        'stores': 'list[CloudStore]'
    }

    attribute_map = {
        'content_service_reference': 'contentServiceReference',
        'context': 'context',
        'document_references': 'documentReferences',
        'end': 'end',
        'exception_details': 'exceptionDetails',
        'file_references': 'fileReferences',
        'id': 'id',
        'options': 'options',
        'processing_time': 'processingTime',
        'start': 'start',
        'status': 'status',
        'stores': 'stores'
    }

    def __init__(self, content_service_reference=None, context=None, document_references=None, end=None, exception_details=None, file_references=None, id=None, options=None, processing_time=None, start=None, status=None, stores=None):  # noqa: E501
        """CloudExecutionStep - a model defined in Swagger"""  # noqa: E501
        self._content_service_reference = None
        self._context = None
        self._document_references = None
        self._end = None
        self._exception_details = None
        self._file_references = None
        self._id = None
        self._options = None
        self._processing_time = None
        self._start = None
        self._status = None
        self._stores = None
        self.discriminator = None
        if content_service_reference is not None:
            self.content_service_reference = content_service_reference
        if context is not None:
            self.context = context
        if document_references is not None:
            self.document_references = document_references
        if end is not None:
            self.end = end
        if exception_details is not None:
            self.exception_details = exception_details
        if file_references is not None:
            self.file_references = file_references
        if id is not None:
            self.id = id
        if options is not None:
            self.options = options
        if processing_time is not None:
            self.processing_time = processing_time
        if start is not None:
            self.start = start
        if status is not None:
            self.status = status
        if stores is not None:
            self.stores = stores

    @property
    def content_service_reference(self):
        """Gets the content_service_reference of this CloudExecutionStep.  # noqa: E501


        :return: The content_service_reference of this CloudExecutionStep.  # noqa: E501
        :rtype: ContentServiceReference
        """
        return self._content_service_reference

    @content_service_reference.setter
    def content_service_reference(self, content_service_reference):
        """Sets the content_service_reference of this CloudExecutionStep.


        :param content_service_reference: The content_service_reference of this CloudExecutionStep.  # noqa: E501
        :type: ContentServiceReference
        """

        self._content_service_reference = content_service_reference

    @property
    def context(self):
        """Gets the context of this CloudExecutionStep.  # noqa: E501


        :return: The context of this CloudExecutionStep.  # noqa: E501
        :rtype: object
        """
        return self._context

    @context.setter
    def context(self, context):
        """Sets the context of this CloudExecutionStep.


        :param context: The context of this CloudExecutionStep.  # noqa: E501
        :type: object
        """

        self._context = context

    @property
    def document_references(self):
        """Gets the document_references of this CloudExecutionStep.  # noqa: E501


        :return: The document_references of this CloudExecutionStep.  # noqa: E501
        :rtype: list[CloudDocumentReference]
        """
        return self._document_references

    @document_references.setter
    def document_references(self, document_references):
        """Sets the document_references of this CloudExecutionStep.


        :param document_references: The document_references of this CloudExecutionStep.  # noqa: E501
        :type: list[CloudDocumentReference]
        """

        self._document_references = document_references

    @property
    def end(self):
        """Gets the end of this CloudExecutionStep.  # noqa: E501


        :return: The end of this CloudExecutionStep.  # noqa: E501
        :rtype: datetime
        """
        return self._end

    @end.setter
    def end(self, end):
        """Sets the end of this CloudExecutionStep.


        :param end: The end of this CloudExecutionStep.  # noqa: E501
        :type: datetime
        """

        self._end = end

    @property
    def exception_details(self):
        """Gets the exception_details of this CloudExecutionStep.  # noqa: E501


        :return: The exception_details of this CloudExecutionStep.  # noqa: E501
        :rtype: ExceptionDetails
        """
        return self._exception_details

    @exception_details.setter
    def exception_details(self, exception_details):
        """Sets the exception_details of this CloudExecutionStep.


        :param exception_details: The exception_details of this CloudExecutionStep.  # noqa: E501
        :type: ExceptionDetails
        """

        self._exception_details = exception_details

    @property
    def file_references(self):
        """Gets the file_references of this CloudExecutionStep.  # noqa: E501


        :return: The file_references of this CloudExecutionStep.  # noqa: E501
        :rtype: list[CloudFileReference]
        """
        return self._file_references

    @file_references.setter
    def file_references(self, file_references):
        """Sets the file_references of this CloudExecutionStep.


        :param file_references: The file_references of this CloudExecutionStep.  # noqa: E501
        :type: list[CloudFileReference]
        """

        self._file_references = file_references

    @property
    def id(self):
        """Gets the id of this CloudExecutionStep.  # noqa: E501


        :return: The id of this CloudExecutionStep.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this CloudExecutionStep.


        :param id: The id of this CloudExecutionStep.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def options(self):
        """Gets the options of this CloudExecutionStep.  # noqa: E501


        :return: The options of this CloudExecutionStep.  # noqa: E501
        :rtype: object
        """
        return self._options

    @options.setter
    def options(self, options):
        """Sets the options of this CloudExecutionStep.


        :param options: The options of this CloudExecutionStep.  # noqa: E501
        :type: object
        """

        self._options = options

    @property
    def processing_time(self):
        """Gets the processing_time of this CloudExecutionStep.  # noqa: E501


        :return: The processing_time of this CloudExecutionStep.  # noqa: E501
        :rtype: int
        """
        return self._processing_time

    @processing_time.setter
    def processing_time(self, processing_time):
        """Sets the processing_time of this CloudExecutionStep.


        :param processing_time: The processing_time of this CloudExecutionStep.  # noqa: E501
        :type: int
        """

        self._processing_time = processing_time

    @property
    def start(self):
        """Gets the start of this CloudExecutionStep.  # noqa: E501


        :return: The start of this CloudExecutionStep.  # noqa: E501
        :rtype: datetime
        """
        return self._start

    @start.setter
    def start(self, start):
        """Sets the start of this CloudExecutionStep.


        :param start: The start of this CloudExecutionStep.  # noqa: E501
        :type: datetime
        """

        self._start = start

    @property
    def status(self):
        """Gets the status of this CloudExecutionStep.  # noqa: E501


        :return: The status of this CloudExecutionStep.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this CloudExecutionStep.


        :param status: The status of this CloudExecutionStep.  # noqa: E501
        :type: str
        """
        allowed_values = ["PENDING", "RUNNING", "SUCCEEDED", "FAILED", "REQUESTED"]  # noqa: E501
        if status not in allowed_values:
            raise ValueError(
                "Invalid value for `status` ({0}), must be one of {1}"  # noqa: E501
                .format(status, allowed_values)
            )

        self._status = status

    @property
    def stores(self):
        """Gets the stores of this CloudExecutionStep.  # noqa: E501


        :return: The stores of this CloudExecutionStep.  # noqa: E501
        :rtype: list[CloudStore]
        """
        return self._stores

    @stores.setter
    def stores(self, stores):
        """Sets the stores of this CloudExecutionStep.


        :param stores: The stores of this CloudExecutionStep.  # noqa: E501
        :type: list[CloudStore]
        """

        self._stores = stores

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CloudExecutionStep, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CloudExecutionStep):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Kodexa

    Content Intelligence  # noqa: E501

    OpenAPI spec version: 2.0.132
    Contact: suppot@kodexa.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from kodexa_cloud.api_client import ApiClient


class ContentServicesEndpointControllerApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def process_using_get1(self, organization_slug, service_slug, **kwargs):  # noqa: E501
        """process  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.process_using_get1(organization_slug, service_slug, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str organization_slug: organizationSlug (required)
        :param str service_slug: serviceSlug (required)
        :return: ContentServiceVersion
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.process_using_get1_with_http_info(organization_slug, service_slug, **kwargs)  # noqa: E501
        else:
            (data) = self.process_using_get1_with_http_info(organization_slug, service_slug, **kwargs)  # noqa: E501
            return data

    def process_using_get1_with_http_info(self, organization_slug, service_slug, **kwargs):  # noqa: E501
        """process  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.process_using_get1_with_http_info(organization_slug, service_slug, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str organization_slug: organizationSlug (required)
        :param str service_slug: serviceSlug (required)
        :return: ContentServiceVersion
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['organization_slug', 'service_slug']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method process_using_get1" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'organization_slug' is set
        if ('organization_slug' not in params or
                params['organization_slug'] is None):
            raise ValueError("Missing the required parameter `organization_slug` when calling `process_using_get1`")  # noqa: E501
        # verify the required parameter 'service_slug' is set
        if ('service_slug' not in params or
                params['service_slug'] is None):
            raise ValueError("Missing the required parameter `service_slug` when calling `process_using_get1`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'organization_slug' in params:
            path_params['organizationSlug'] = params['organization_slug']  # noqa: E501
        if 'service_slug' in params:
            path_params['serviceSlug'] = params['service_slug']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/api/processing/services/{organizationSlug}/{serviceSlug}/latest', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ContentServiceVersion',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Kodexa

    Content Intelligence  # noqa: E501

    OpenAPI spec version: 2.0.132
    Contact: suppot@kodexa.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class CloudBotSession(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'documents': 'list[CloudDocument]',
        'files': 'list[CloudFile]',
        'id': 'str',
        'last_accessed': 'int',
        'pipeline_templates': 'list[CloudPipeline]',
        'session_state': 'str',
        'type': 'str',
        'bot': 'Bot',
        'bot_state': 'object'
    }
    if hasattr(CloudSession, "swagger_types"):
        swagger_types.update(CloudSession.swagger_types)

    attribute_map = {
        'documents': 'documents',
        'files': 'files',
        'id': 'id',
        'last_accessed': 'lastAccessed',
        'pipeline_templates': 'pipelineTemplates',
        'session_state': 'sessionState',
        'type': 'type',
        'bot': 'bot',
        'bot_state': 'botState'
    }
    if hasattr(CloudSession, "attribute_map"):
        attribute_map.update(CloudSession.attribute_map)

    def __init__(self, documents=None, files=None, id=None, last_accessed=None, pipeline_templates=None, session_state=None, type=None, bot=None, bot_state=None, *args, **kwargs):  # noqa: E501
        """CloudBotSession - a model defined in Swagger"""  # noqa: E501
        self._documents = None
        self._files = None
        self._id = None
        self._last_accessed = None
        self._pipeline_templates = None
        self._session_state = None
        self._type = None
        self._bot = None
        self._bot_state = None
        self.discriminator = None
        if documents is not None:
            self.documents = documents
        if files is not None:
            self.files = files
        self.id = id
        if last_accessed is not None:
            self.last_accessed = last_accessed
        if pipeline_templates is not None:
            self.pipeline_templates = pipeline_templates
        self.session_state = session_state
        self.type = type
        if bot is not None:
            self.bot = bot
        if bot_state is not None:
            self.bot_state = bot_state
        CloudSession.__init__(self, *args, **kwargs)

    @property
    def documents(self):
        """Gets the documents of this CloudBotSession.  # noqa: E501


        :return: The documents of this CloudBotSession.  # noqa: E501
        :rtype: list[CloudDocument]
        """
        return self._documents

    @documents.setter
    def documents(self, documents):
        """Sets the documents of this CloudBotSession.


        :param documents: The documents of this CloudBotSession.  # noqa: E501
        :type: list[CloudDocument]
        """

        self._documents = documents

    @property
    def files(self):
        """Gets the files of this CloudBotSession.  # noqa: E501


        :return: The files of this CloudBotSession.  # noqa: E501
        :rtype: list[CloudFile]
        """
        return self._files

    @files.setter
    def files(self, files):
        """Sets the files of this CloudBotSession.


        :param files: The files of this CloudBotSession.  # noqa: E501
        :type: list[CloudFile]
        """

        self._files = files

    @property
    def id(self):
        """Gets the id of this CloudBotSession.  # noqa: E501


        :return: The id of this CloudBotSession.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this CloudBotSession.


        :param id: The id of this CloudBotSession.  # noqa: E501
        :type: str
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def last_accessed(self):
        """Gets the last_accessed of this CloudBotSession.  # noqa: E501


        :return: The last_accessed of this CloudBotSession.  # noqa: E501
        :rtype: int
        """
        return self._last_accessed

    @last_accessed.setter
    def last_accessed(self, last_accessed):
        """Sets the last_accessed of this CloudBotSession.


        :param last_accessed: The last_accessed of this CloudBotSession.  # noqa: E501
        :type: int
        """

        self._last_accessed = last_accessed

    @property
    def pipeline_templates(self):
        """Gets the pipeline_templates of this CloudBotSession.  # noqa: E501


        :return: The pipeline_templates of this CloudBotSession.  # noqa: E501
        :rtype: list[CloudPipeline]
        """
        return self._pipeline_templates

    @pipeline_templates.setter
    def pipeline_templates(self, pipeline_templates):
        """Sets the pipeline_templates of this CloudBotSession.


        :param pipeline_templates: The pipeline_templates of this CloudBotSession.  # noqa: E501
        :type: list[CloudPipeline]
        """

        self._pipeline_templates = pipeline_templates

    @property
    def session_state(self):
        """Gets the session_state of this CloudBotSession.  # noqa: E501


        :return: The session_state of this CloudBotSession.  # noqa: E501
        :rtype: str
        """
        return self._session_state

    @session_state.setter
    def session_state(self, session_state):
        """Sets the session_state of this CloudBotSession.


        :param session_state: The session_state of this CloudBotSession.  # noqa: E501
        :type: str
        """
        if session_state is None:
            raise ValueError("Invalid value for `session_state`, must not be `None`")  # noqa: E501
        allowed_values = ["OPEN", "CLOSED"]  # noqa: E501
        if session_state not in allowed_values:
            raise ValueError(
                "Invalid value for `session_state` ({0}), must be one of {1}"  # noqa: E501
                .format(session_state, allowed_values)
            )

        self._session_state = session_state

    @property
    def type(self):
        """Gets the type of this CloudBotSession.  # noqa: E501


        :return: The type of this CloudBotSession.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this CloudBotSession.


        :param type: The type of this CloudBotSession.  # noqa: E501
        :type: str
        """
        if type is None:
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501

        self._type = type

    @property
    def bot(self):
        """Gets the bot of this CloudBotSession.  # noqa: E501


        :return: The bot of this CloudBotSession.  # noqa: E501
        :rtype: Bot
        """
        return self._bot

    @bot.setter
    def bot(self, bot):
        """Sets the bot of this CloudBotSession.


        :param bot: The bot of this CloudBotSession.  # noqa: E501
        :type: Bot
        """

        self._bot = bot

    @property
    def bot_state(self):
        """Gets the bot_state of this CloudBotSession.  # noqa: E501


        :return: The bot_state of this CloudBotSession.  # noqa: E501
        :rtype: object
        """
        return self._bot_state

    @bot_state.setter
    def bot_state(self, bot_state):
        """Sets the bot_state of this CloudBotSession.


        :param bot_state: The bot_state of this CloudBotSession.  # noqa: E501
        :type: object
        """

        self._bot_state = bot_state

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CloudBotSession, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CloudBotSession):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
